@@ -23,7 +23,6 @@ class BaseEncryptedField(models.Field):
         if not hasattr(settings, 'ENCRYPTED_FIELD_KEYS_DIR'):
             raise ImproperlyConfigured('You must set the ENCRYPTED_FIELD_KEYS_DIR '
                                        'setting to your Keyczar keys directory.')
-
         crypt_class = self.get_crypt_class()
         self.crypt = crypt_class.Read(settings.ENCRYPTED_FIELD_KEYS_DIR)
 
@@ -67,9 +66,12 @@ class BaseEncryptedField(models.Field):
         if isinstance(self.crypt.primary_key, keyczar.keys.RsaPublicKey):
             retval = value
         elif value and (value.startswith(self.prefix)):
-            retval = self.crypt.Decrypt(value[len(self.prefix):])
-            if retval:
-                retval = retval.decode('utf-8')
+            if hasattr(self.crypt, 'Decrypt'):
+                retval = self.crypt.Decrypt(value[len(self.prefix):])
+                if retval:
+                    retval = retval.decode('utf-8')
+            else:
+                retval = value
         else:
             retval = value
         return retval
