@@ -228,7 +228,7 @@ class SQLDiff(object):
 
     def strip_parameters(self, field_type):
         if field_type and field_type != 'double precision':
-            return field_type.split(" ")[0].split("(")[0]
+            return field_type.split(" ")[0].split("(")[0].lower()
         return field_type
 
     def find_unique_missing_in_db(self, meta, table_indexes, table_name):
@@ -289,14 +289,14 @@ class SQLDiff(object):
                 continue
             description = db_fields[field.name]
 
-            model_type = self.strip_parameters(self.get_field_model_type(field))
-            db_type = self.strip_parameters(self.get_field_db_type(description, field))
+            model_type = self.get_field_model_type(field)
+            db_type = self.get_field_db_type(description, field)
 
             # use callback function if defined
             if func:
                 model_type, db_type = func(field, description, model_type, db_type)
 
-            if not model_type == db_type:
+            if not self.strip_parameters(db_type) == self.strip_parameters(model_type):
                 self.add_difference('field-type-differ', table_name, field.name, model_type, db_type)
 
     def find_field_parameter_differ(self, meta, table_description, table_name, func=None):
@@ -553,8 +553,11 @@ class PostgresqlSQLDiff(SQLDiff):
         if not db_type:
             return
         if field:
-            if field.primary_key and db_type == 'integer':
-                db_type = 'serial'
+            if field.primary_key:
+                if db_type == 'integer':
+                    db_type = 'serial'
+                elif db_type == 'bigint':
+                    db_type = 'bigserial'
             if table_name:
                 tablespace = field.db_tablespace
                 if tablespace == "":
